The Contributors License Agreement
==========================================

Version 1.0
-----------
I agree to contribute to pyvisco, a python library that supports Prony series 
identification of linear viscoelastic material models.
I agree to the following terms and conditions for my contributions: 
First, I agree that I am licensing the copyright to my contributions 
under the terms of the current pyvisco license. 
Second, I agree that, in order to conform to any future open source 
software license(s) under which pyvisco may be provided, the terms of 
my copyright license may be modified without any notice to me and 
without my consent. 
Third, I hereby grant to Alliance for Sustainable Energy, LLC, 
to any successor manager and distributor of pyvisco appointed by 
the U.S. Department of Energy, and to all recipients of 
a version of pyvisco that includes my contributions, a non-exclusive, 
worldwide, royalty-free, irrevocable patent license under any patent 
claims owned by me, or owned by my employer and known to me, that 
are or will be, necessarily infringed upon by my contributions alone, 
or by combination of my contributions with the version of pyvisco 
to which they are contributed, to make, have made, use, offer to sell, 
sell, import, and otherwise transfer any version of pyvisco that 
includes my contributions, in source code and object code form. 
Fourth, I represent and warrant that I am authorized to make the 
contributions and grant the foregoing license(s). 
Additionally, if, to my knowledge, my employer has rights to 
intellectual property that covers my contributions, I represent 
and warrant that I have received permission to make these contributions 
and grant the foregoing license(s) on behalf of my employer.